Package: COSNet
Type: Package
Title: Cost Sensitive Network for node label prediction on graphs with
        highly unbalanced labelings
Version: 1.47.0
Date: 2015-11-06
Author: Marco Frasca and Giorgio Valentini -- Universita' degli Studi
        di Milano
Maintainer: Marco Frasca<frasca@di.unimi.it>
Description: Package that implements the COSNet classification
        algorithm. The algorithm predicts node labels in partially
        labeled graphs where few positives are available for the class
        being predicted.
License: GPL (>= 2)
URL: https://github.com/m1frasca/COSNet_GitHub
LazyLoad: yes
Suggests: bionetdata, PerfMeas, RUnit, BiocGenerics
biocViews: GraphAndNetwork, Classification,Network, NeuralNetwork
Repository: https://bioc.r-universe.dev
Date/Publication: 2026-04-28 12:40:11 UTC
RemoteUrl: https://github.com/bioc/COSNet
RemoteRef: HEAD
RemoteSha: 88518b6b6f351d2ee367cb83e97f2afde4fcb752
NeedsCompilation: yes
Packaged: 2026-05-30 08:44:25 UTC; root
Built: R 4.6.0; x86_64-apple-darwin20; 2026-05-30 08:47:56 UTC; unix
